Gestione campionati — SoL 4, manuale utente

# Gestione campionati

Un campionato raggruppa uno o più tornei, organizzati dallo stesso club, con regole di gioco omogenee: tutti i tornei di uno stesso campionato sono necessariamente tutti singoli oppure a squadre e usano il medesimo metodo di assegnazione dei premi finali.

Indice

- Gestione campionati

  - Voci del menu

  - Inserimento e modifica

    - Club e descrizione

    - Giocatori

    - Scarta

    - Partite solitarie

    - Valutazione

    - Abbinamenti

    - Premi

    - Concluso

    - Campionato precedente

    - Responsabile

## Voci del menu

Oltre alle azioni standard il menu contiene queste voci:

Gestione campionati

Tornei

  Apre la gestione dei tornei organizzati nell'ambito del campionato selezionato

Club

  Apre la gestione dei club filtrata sul club che organizza il campionato selezionato

Scarica

  Permette di scaricare i dati di tutti i tornei organizzati nell'ambito del campionato selezionato

Classifica

  Produce un documento PDF con la classifica del campionato selezionato

Assegna

  Assegna la responsabilità dei campionati selezionati: è possibile selezionare uno o più campionati tenendo premuto il tasto `Ctrl` ed estendere la selezione premendo il tasto `Shift`

## Inserimento e modifica

### Club e descrizione

Ogni campionato appartiene a un particolare club e ha una descrizione che deve essere univoca per lo stesso club.

### Giocatori

Giocatori per squadra determina il numero massimo di giocatori che compongono un singolo concorrente: 1 per i singoli, 2 per il doppio e fino a 4 per i tornei a squadre.

### Scarta

Con ignora i peggiori risultati si specifica quanti risultati peggiori di ogni giocatore verranno ignorati nel calcolo della classifica di fine campionato. In genere viene usato per consentire ai giocatori di non partecipare a tutte le tappe di un campionato e di rimanere comunque in competizione.

### Partite solitarie

Di solito lasciato in bianco, se inserito è il numero di partite che dovranno essere giocate da ciascun partecipante a un torneo in solitudine associato al campionato.

In questo tipo di tornei, lo score di ciascun giocatore viene calcolato dalla media dei tiri sbagliati, cioè dal numero di tiri che non imbucano nessuna pedina, nel corso di diverse partite consecutive.

Quei valori possono essere inseriti come al solito, oppure inseriti direttamente dai giocatori stessi, usando un modulo che devono compilare alla fine di ciascun turno: ogni volta che il gestore del torneo genera un nuovo turno, può usare l'azione Invia email del pannello incontri (visibile solo in questo tipo di tornei) per spedire a ciascun concorrente una mail con l'URL da visitare.

È chiaramente compito del gestore del torneo controllare che i valori immessi siano corretti: di tanto in tanto dovrà usare l'azione Aggiorna per ricaricare gli incontri, e quando tutti i punteggi siano stati inseriti correttamente potrà usare l'azione Ricalcola classifica e poi procedere alla generazione del turno successivo.

### Valutazione

La valutazione viene usata come valore di default quando si creano nuovi tornei nel campionato: generalmente, ma non sempre, tutti i tornei di un campionato fanno riferimento ad una medesima valutazione; è comunque l'impostazione sul torneo ad essere determinante, in quanto può verificarsi che un particolare evento faccia sì parte di un campionato ma usi una diversa valutazione, ad esempio quando c'è un torneo open.

### Abbinamenti

Il metodo abbinamenti viene usato come valore di default quando si creano nuovi tornei nel campionato e determina come verranno create le coppie di avversari ad ogni nuovo turno (vedi sistema di generazione abbinamenti del torneo per i dettagli).

### Premi

Il metodo premiazione determina come verranno assegnati i premi finali. Tali premi hanno due funzioni primarie:

1. uniformare, rendendo quindi sommabili, i risultati dei singoli tornei per produrre la classifica del campionato

2. essendo di fatto liberamente assegnabili, consentono di invertire la posizione dei primi due (o quattro) giocatori qualora l'eventuale finale tra il primo e il secondo classificato (e tra il terzo e il quarto) dovesse così stabilire

Un caso particolare è il valore `Nessun premio finale`, che in pratica significa la premiazione assegnerà semplicemente una sequenza decrescente di numeri interi a cominciare dal numero di concorrenti fino a 1 come premio finale, solo al fine di consentire l'aggiustamento delle posizioni in classifica al termine dei turni finali del torneo. Questo premi non compariranno nella stampa della classifica del torneo. Inoltre, nella classifica del campionato non verranno considerati i premi finali dei concorrenti, bensì il loro punteggio.

I rimanenti quattro valori identificano altrettanti metodi di generazione dei premi finali:

`Premi fissi`

  assegna 18 punti al primo, 16 al secondo, 14 al terzo, 13 al quarto e così via fino al sedicesimo piazzamento;

`40 premi fissi`

  assegna 1000 punti al primo, 900 al secondo, 800 al terzo, 750 al quarto e così via, fino a un punto per il quarantesimo classificato;

`Millesimale classico`

  assegna 1000 punti al vincitore e un premio proporzionale a tutti gli altri; in genere è il metodo preferito quando il numero di concorrenti è maggiore di 20 o giù di lì;

`Centesimale`

  assegna 100 punti al vincitore, 1 punto all'ultimo classificato, interpolando linearmente il premio da assegnare agli altri concorrenti.

### Concluso

Il campo concluso indica se il campionato è terminato: in questo caso nessun altro torneo potrà esservi associato e pertanto il selettore di campionato (ad esempio inserendo nuovi tornei) mostrerà solo quelli ancora attivi.

### Campionato precedente

Il campo campionato precedente consente di consultare le varie stagioni di tornei. È possibile selezionare solo campionati conclusi.

### Responsabile

Il responsabile generalmente indica l'utente che ha inserito quel particolare campionato: i dati del campionato potranno essere modificati solo da lui (oltre che dall'amministratore del sistema.).